@@ -90,10 +90,10 @@ class CliArgsConfig:
 
 #### From old Setu code
 from arjuna.core.enums import *
-from arjuna.core.value import AnyRefValue
+from arjuna.core.value import Value
 
 
-class DefaultTestConfig:
+class Configuration:
 
     def __init__(self, test_session, name, config):
         super().__init__()
@@ -120,17 +120,17 @@ class DefaultTestConfig:
 
     @staticmethod
     def normalize_arjuna_option_str(option_str):
-        return ArjunaOption[DefaultTestConfig.normalize_option_str(option_str)]
+        return ArjunaOption[Configuration.normalize_option_str(option_str)]
 
     def get_arjuna_option_value(self, option):
         arjuna_option = option
         if type(option) is str:
-            arjuna_option = DefaultTestConfig.normalize_arjuna_option_str(option)
-        return AnyRefValue(self.__wrapped_config.arjuna_config.value(arjuna_option))
+            arjuna_option = Configuration.normalize_arjuna_option_str(option)
+        return Value(self.__wrapped_config.arjuna_config.value(arjuna_option))
 
     def get_user_option_value(self, option):
-        user_option = DefaultTestConfig.normalize_option_str(option)
-        return AnyRefValue(self.__wrapped_config.user_config.value(user_option))
+        user_option = Configuration.normalize_option_str(option)
+        return Value(self.__wrapped_config.user_config.value(user_option))
 
     def get_arjuna_options_as_map(self):
         return self.__wrapped_config.arjuna_config.as_json_dict()
@@ -147,7 +147,7 @@ class DefaultTestConfig:
         return self.get_arjuna_option_value(ArjunaOption.GUIAUTO_CONTEXT).as_enum(GuiAutomationContext)
 
     @property
-    def browser_type(self):
+    def browser_name(self):
         return self.get_arjuna_option_value(ArjunaOption.BROWSER_NAME).as_enum(BrowserName)
 
     @property
@@ -171,7 +171,7 @@ class DefaultTestConfig:
         return self.get_arjuna_option_value(ArjunaOption.LOG_DIR).as_str()
 
     @property
-    def guiauto_max_wait_time(self):
+    def guiauto_max_wait(self):
         return self.get_arjuna_option_value(ArjunaOption.GUIAUTO_MAX_WAIT).as_int()
 
     def as_map(self):
