@@ -98,48 +98,6 @@ class ArjunaOption(Enum):
 
     IMAGE_COMPARISON_MIN_SCORE = auto()
 
-    UNITEE_PROJECT_DIRS_FILES = auto()
-    UNITEE_PROJECT_SESSIONS_DIR = auto()
-    UNITEE_PROJECT_GROUPS_DIR = auto()
-    UNITEE_PROJECT_TESTS_DIR = auto()
-    UNITEE_PROJECT_TEST_MODULE_IMPORT_PREFIX = auto()
-    UNITEE_PROJECT_FIXTURES_IMPORT_PREFIX = auto()
-    UNITEE_PROJECT_CORE_DIR = auto()
-    UNITEE_PROJECT_CORE_DB_CENTRAL_DIR = auto()
-    UNITEE_PROJECT_CORE_DB_CENTRAL_DBFILE = auto()
-    UNITEE_PROJECT_CORE_DB_RUN_DBFILE = auto()
-    UNITEE_PROJECT_CORE_DB_ALLRUN_DIR = auto()
-    UNITEE_PROJECT_CORE_DB_TEMPLATE_DIR = auto()
-    UNITEE_PROJECT_CORE_DB_TEMPLATE_CENTRAL_DBFILE = auto()
-    UNITEE_PROJECT_CORE_DB_TEMPLATE_RUN_DBFILE = auto()
-    UNITEE_PROJECT_REPORTER_MODE = auto()
-    UNITEE_PROJECT_ACTIVE_REPORTERS = auto()
-    UNITEE_PROJECT_DEFERRED_REPORTERS = auto()
-    UNITEE_PROJECT_FAILFAST = auto()
-    UNITEE_PROJECT_REPORT_NAME_FORMAT = auto()
-    UNITEE_PROJECT_REPORT_HEADERS_TMETA = auto()
-    UNITEE_PROJECT_REPORT_HEADERS_IGMETA = auto()
-    UNITEE_PROJECT_REPORT_HEADERS_PROPS = auto()
-    UNITEE_PROJECT_REPORT_HEADERS_REPORTABLE_TEST = auto()
-    UNITEE_PROJECT_REPORT_HEADERS_REPORTABLE_STEP = auto()
-    UNITEE_PROJECT_REPORT_HEADERS_REPORTABLE_ISSUE = auto()
-    UNITEE_PROJECT_REPORT_HEADERS_REPORTABLE_IGNORED = auto()
-    UNITEE_PROJECT_REPORT_HEADERS_REPORTABLE_FIXTURE = auto()
-    UNITEE_PROJECT_REPORT_HEADERS_REPORTABLE_EVENT = auto()
-    UNITEE_PROJECT_RUNID = auto()
-    UNITEE_PROJECT_IRUNID = auto()
-    UNITEE_PROJECT_SESSION_NAME = auto()
-    UNITEE_PROJECT_CORE = auto()
-    UNITEE_PROJECT_SCREENSHOTS_RUN_DIR = auto()
-    UNITEE_PROJECT_RUN_REPORT_DIR = auto()
-    UNITEE_PROJECT_RUN_REPORT_JDB_DIR = auto()
-    UNITEE_PROJECT_RUN_REPORT_JSON_DIR = auto()
-    UNITEE_PROJECT_RUN_REPORT_JSON_TESTS_DIR = auto()
-    UNITEE_PROJECT_RUN_REPORT_JSON_IGNOREDTESTS_DIR = auto()
-    UNITEE_PROJECT_RUN_REPORT_JSON_ISSUES_DIR = auto()
-    UNITEE_PROJECT_RUN_REPORT_JSON_EVENTS_DIR = auto()
-    UNITEE_PROJECT_RUN_REPORT_JSON_FIXTURES_DIR = auto()
-
 
 class Key(Enum):
 	NULL = auto()
