@@ -1,4 +1,24 @@
+'''
+This file is a part of Arjuna
+Copyright 2015-2020 Rahul Verma
+
+Website: www.RahulVerma.net
+
+Licensed under the Apache License, Version 2.0 (the "License");
+you may not use this file except in compliance with the License.
+You may obtain a copy of the License at
+
+  http://www.apache.org/licenses/LICENSE-2.0
+
+Unless required by applicable law or agreed to in writing, software
+distributed under the License is distributed on an "AS IS" BASIS,
+WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+See the License for the specific language governing permissions and
+limitations under the License.
+'''
+
 import time
+import traceback
 
 from arjuna.core.exceptions import *
 
@@ -43,14 +63,12 @@ class Condition:
             except Exception as f:
                 import traceback
                 traceback.print_exc()
-                raise("An unexpected exception occured in dynamic wait.")
+                raise Exception("An unexpected exception occured in dynamic wait. Message: {}".format(str(f)))
             time.sleep(poll_interval)
             ctime = time.time()
             if(ctime > end_time):
                 break
-        print(e)
-        print(etrace)
-        raise Exception("Timeout in wait.")
+        raise TimeoutError(self.__class__.__name__, str(e) + etrace)
 
     def execute(self):
         self.__call_result = self.__dynamic_caller.call(*self.__args, **self.__kwargs)
@@ -77,7 +95,6 @@ class BooleanCondition(Condition):
             self.execute()
             return self.__expectation_type == self.get_call_result()
         except Exception as e:
-            print(e)
             import traceback
             traceback.print_exc()
             raise ConditionException("Unexpected exception in boolean condition checking: " + str(e))
\ No newline at end of file
