@@ -1,6 +1,26 @@
+'''
+This file is a part of Arjuna
+Copyright 2015-2020 Rahul Verma
+
+Website: www.RahulVerma.net
+
+Licensed under the Apache License, Version 2.0 (the "License");
+you may not use this file except in compliance with the License.
+You may obtain a copy of the License at
+
+  http://www.apache.org/licenses/LICENSE-2.0
+
+Unless required by applicable law or agreed to in writing, software
+distributed under the License is distributed on an "AS IS" BASIS,
+WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+See the License for the specific language governing permissions and
+limitations under the License.
+'''
+
 import base64
 import os
 import time
+import datetime
 
 from arjuna.core.enums import ArjunaOption
 from arjuna.interact.gui.auto.base.container import ElementContainer
@@ -9,6 +29,7 @@ from .drivercaps import DriverCapabilities
 from arjuna.interact.gui.auto.source.parser import ElementXMLSourceParser
 from arjuna.interact.gui.dispatcher.selenium.driver import SeleniumDriverDispatcher
 from arjuna.interact.gui.auto.finder.emd import GuiElementMetaData
+from arjuna.interact.gui.auto.element.guielement import GuiElement
 
 class GuiAutomator(ElementContainer,Dispatchable):
 
@@ -29,6 +50,7 @@ class GuiAutomator(ElementContainer,Dispatchable):
         self.__conditions_handler = GuiAutomatorConditions(self)
         self.__view_handler = ViewContextHandler(self)
         self.__browser = None
+        self.__screenshots_dir = config.get_arjuna_option_value(ArjunaOption.PROJECT_RUN_SCREENSHOTS_DIR).as_str()
 
         self.__source_parser = None
 
@@ -46,6 +68,10 @@ class GuiAutomator(ElementContainer,Dispatchable):
     def ext_config(self):
         return self.__econfig
 
+    @property
+    def screenshots_dir(self):
+        return self.__screenshots_dir
+
     def create_lmd(self, *locators):
         return GuiElementMetaData.create_lmd(*locators)
 
@@ -77,6 +103,23 @@ class GuiAutomator(ElementContainer,Dispatchable):
     def main_window(self):
         return self.__main_window
 
+    def child_window(self, lmd):
+        return self.main_window.child_window(lmd)
+
+    @property
+    def latest_child_window(self):
+        return self.main_window.latest_child_window
+
+    def close_all_child_windows(self):
+        self.main_window.close_all_child_windows()
+
+    def dom_root(self, gui):
+        from arjuna.interact.gui.auto.component.frame import DomRoot
+        return DomRoot(gui)
+
+    def frame(self, gui, lmd, iconfig=None):
+        return self.dom_root(gui).frame(lmd, iconfig=iconfig)
+        
     @property
     def alert_handler(self):
         return self.__alert_handler
@@ -90,7 +133,7 @@ class GuiAutomator(ElementContainer,Dispatchable):
         return self.__conditions_handler
 
     def __create_screenshots_dir(self):
-        sdir = self.config.get_arjuna_option_value(ArjunaOption.SCREENSHOTS_DIR).as_str()
+        sdir = self.config.get_arjuna_option_value(ArjunaOption.PROJECT_RUN_SCREENSHOTS_DIR).as_str()
         if not os.path.isdir(sdir):
             os.makedirs(sdir)
 
@@ -103,7 +146,7 @@ class GuiAutomator(ElementContainer,Dispatchable):
         self.dispatcher.launch(caps.processed_config)
 
         from arjuna.interact.gui.auto.component.window import MainWindow
-        self.__main_window = MainWindow(self)
+        self.__main_window = MainWindow(self.app, self)
 
         from .browser import Browser
         self.__browser = Browser(self)
@@ -113,28 +156,34 @@ class GuiAutomator(ElementContainer,Dispatchable):
     def quit(self):
         self.dispatcher.quit()
 
-    def __screenshot(self):
-        switch_view_context = None
-        if self.config.value(ArjunaOption.MOBILE_OS_NAME).lower() == "android":
-            view_name = self.view_handler.get_current_view_context()   
-            if self.view_handler._does_name_represent_web_view(view_name) :
-                self.view_handler.switch_to_native_view() 
-                switch_view_context = view_name
+    def __screenshot(self, file_path):
+        # switch_view_context = None
+        # if self.config.value(ArjunaOption.MOBILE_OS_NAME).lower() == "android":
+        #     view_name = self.view_handler.get_current_view_context()   
+        #     if self.view_handler._does_name_represent_web_view(view_name) :
+        #         self.view_handler.switch_to_native_view() 
+        #         switch_view_context = view_name
 
-        response = self.dispatcher.take_screenshot()
+        self.dispatcher.take_screenshot(file_path)
 
-        if switch_view_context:
-            self.view_handler.switch_to_view_context(switch_view_context)
-        
-        return response
+        # if switch_view_context:
+        #     self.view_handler.switch_to_view_context(switch_view_context)
 
-    def take_screenshot(self):
-        response = self.__screenshot()
-        image = base64.b64decode(response["data"]["codedImage"])
-        path = os.path.join(self.config.value(ArjunaOption.SCREENSHOTS_DIR), "{}.png".format(str(time.time()).replace(".", "-")))
-        f = open(path, "wb")
+    def take_screenshot(self, name=None):
+        image_b64 = self.dispatcher.take_screenshot_as_base64()
+        image = base64.b64decode(image_b64)
+
+        ts = datetime.datetime.now().strftime("%Y-%m-%d-%H-%M-%S-%f")[:-3]
+        if name:
+            name = name.replace("..", "") + "-"
+        else:
+            name = ""
+        file_name = "{}{}.png".format(name, ts)
+        fpath = os.path.join(self.screenshots_dir, file_name)
+        f = open(fpath, "wb")
         f.write(image)
         f.close()
+        return "../screenshots/{}".format(file_name), image_b64
 
     def focus_on_main_window(self):
         self.main_window.focus()
@@ -153,46 +202,53 @@ class GuiAutomator(ElementContainer,Dispatchable):
 
     def find_multielement_with_js(self, js):
         return self.dispatcher.find_multielement_with_js(js)
-
-
     '''
         Public API
     '''
 
     #### Element Finding
 
-    def element(self, lmd):
+    def element(self, gui, lmd, iconfig=None, max_wait_time=None):
         from arjuna.interact.gui.auto.element.guielement import GuiElement
-        gui_element = GuiElement(self, lmd) 
-        self.load_element(gui_element)
+        gui_element = GuiElement(gui, lmd, iconfig=iconfig) 
+        self.load_element(gui_element, max_wait_time=max_wait_time)
         return gui_element
 
-    def multi_element(self, lmd):
+    element_with_lmd = element
+
+    def multi_element(self, gui, lmd, iconfig=None, max_wait_time=None):
         from arjuna.interact.gui.auto.element.multielement import GuiMultiElement
-        m_guielement = GuiMultiElement(self, lmd)
-        self.load_multielement(m_guielement)
+        m_guielement = GuiMultiElement(gui, lmd, iconfig=iconfig)
+        self.load_multielement(m_guielement, max_wait_time=max_wait_time)
         return m_guielement
 
-    def dropdown(self, lmd, option_container_lmd=None, option_lmd=None):
+    multi_element_with_lmd = multi_element
+
+    def dropdown(self, gui, lmd, option_container_lmd=None, option_lmd=None, iconfig=None):
         from arjuna.interact.gui.auto.component.dropdown import GuiWebSelect
-        return GuiWebSelect(self, lmd, option_container_lmd=option_container_lmd, option_lmd=option_lmd)
+        return GuiWebSelect(gui, lmd, option_container_lmd=option_container_lmd, option_lmd=option_lmd, iconfig=iconfig)
 
-    def radio_group(self, lmd):
+    def radio_group(self, gui, lmd, iconfig=None):
         from arjuna.interact.gui.auto.component.radio_group import GuiWebRadioGroup
-        return GuiWebRadioGroup(self, lmd)
+        return GuiWebRadioGroup(gui, lmd)
 
-    def tab_group(self, lmd, *, tab_header_lmd, content_relation_attr, content_relation_type):
+    def tab_group(self, gui, lmd, *, tab_header_lmd, content_relation_attr, content_relation_type, iconfig=None):
         from arjuna.interact.gui.auto.component.tabs import TabGroup
         return TabGroup(
-            self, 
+            gui, 
             lmd, 
             tab_header_lmd=tab_header_lmd, 
             content_relation_attr=content_relation_attr, 
-            content_relation_type=content_relation_type
+            content_relation_type=content_relation_type,
+            iconfig=iconfig
         )
 
-    def execute_javascript(self, js):
-        return self.browser.execute_javascript(js)
+    def execute_javascript(self, js, *args):
+        return self.browser.execute_javascript(js, 
+        *[
+            isinstance(arg, GuiElement) and arg.dispatcher or arg for arg in args
+        ]
+        )
 
     ################################
     # Components
