@@ -61,14 +61,14 @@ class GuiMultiElement(Locatable,Dispatchable,Configurable):
             self.__elements = list()   
         self.__source_parser = None
 
-    # def configure_partial_elements(self, elem_config):
-    #     '''
-    #         This method is supposed to be called when multielement identification is completed.
-    #         This is not used for usual multi-element.
-    #         It is used by RadioGroup or DropDown etc which are higher level abstractions that use ME.
-    #     '''
-    #     for instance in self.__elements:
-    #         instance.configure(elem_config)
+    def configure_partial_elements(self, elem_config):
+        '''
+            This method is supposed to be called when multielement identification is completed.
+            This is not used for usual multi-element.
+            It is used by RadioGroup or DropDown etc which are higher level abstractions that use ME.
+        '''
+        for instance in self.__elements:
+            instance.configure(elem_config)
 
     # def find(self):
     #     self.parent_container.find_multielement(self)
