@@ -1,3 +1,23 @@
+'''
+This file is a part of Arjuna
+Copyright 2015-2020 Rahul Verma
+
+Website: www.RahulVerma.net
+
+Licensed under the Apache License, Version 2.0 (the "License");
+you may not use this file except in compliance with the License.
+You may obtain a copy of the License at
+
+  http://www.apache.org/licenses/LICENSE-2.0
+
+Unless required by applicable law or agreed to in writing, software
+distributed under the License is distributed on an "AS IS" BASIS,
+WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+See the License for the specific language governing permissions and
+limitations under the License.
+'''
+
+
 from .driverelement import SeleniumDriverElementDispatcher
 from arjuna.interact.gui.dispatcher.driver.driver_commands import DriverCommands
 from arjuna.interact.gui.dispatcher.driver.element_finder import ElementFinder
@@ -40,11 +60,18 @@ class SeleniumDriverDispatcher:
     def get_source(self):
         return DriverCommands.get_source(self.__driver)
 
-    def execute_javascript(self, script):
-        return DriverCommands.execute_javascript(self.__driver, script)
+    def execute_javascript(self, script, *args):
+        return DriverCommands.execute_javascript(self.__driver, script, 
+                *[
+                isinstance(arg, SeleniumDriverElementDispatcher) and arg.driver_element or arg for arg in args
+            ]
+        )
 
-    def take_screenshot(self):
-        DriverCommands.take_screenshot(self.__driver)
+    def take_screenshot(self, file_path):
+        DriverCommands.take_screenshot(self.__driver, file_path)
+
+    def take_screenshot_as_base64(self):
+        return DriverCommands.take_screenshot_as_base64(self.__driver)
 
     def find_element(self, with_type, with_value):
         element = ElementFinder.find_element(self.__driver, with_type, with_value)
@@ -85,13 +112,13 @@ class SeleniumDriverDispatcher:
     def find_multielement(self, with_type, with_value):
         web_elements = ElementFinder.find_elements(self.__driver, with_type, with_value)
         melement = MultiElement([SeleniumDriverElementDispatcher(self, web_element) for web_element in web_elements])
-        return melement.get_instance_count(), melement
+        return melement.get_size(), melement
 
     def find_multielement_with_js(self, js):
         web_elements = self.execute_javascript(js)
         web_elements = self.__process_js_multielement(web_elements)
         melement = MultiElement([SeleniumDriverElementDispatcher(self, web_element) for web_element in web_elements])
-        return melement.get_instance_count(), melement
+        return melement.get_size(), melement
 
     def get_current_window_handle(self):
         return DriverCommands.get_current_window_handle(self.__driver)
@@ -148,5 +175,10 @@ class SeleniumDriverDispatcher:
     def hover_on_element(self, element_dispatcher):
         DriverCommands.hover_on_element(self.__driver, element_dispatcher.driver_element)
 
+    def mouse_click_on_element(self, element_dispatcher):
+        DriverCommands.mouse_click_on_element(self.__driver, element_dispatcher.driver_element)
+
+    def scroll_to_element(self, element_dispatcher):
+        DriverCommands.scroll_to_element(self.__driver, element_dispatcher.driver_element)
 
 
