@@ -140,7 +140,7 @@ class Keyboard:
         def parts(self):
             return self.__parts
 
-    @staticmethod
+    @classmethod
     def chord(self):
         '''
             Returns a new KeyChord object.
@@ -175,35 +175,33 @@ class Screen:
 class WithType(Enum):
     ID = auto()
     NAME = auto()
-    CLASS_NAME = auto()
-    LINK_TEXT = auto()
-    LINK_PTEXT = auto()
+    CLASSES = auto()
+    LINK = auto()
+    FLINK = auto()
+    TAG = auto()
     XPATH = auto()
-    CSS_SELECTOR = auto()
-    TAG_NAME = auto()
-    COMPOUND_CLASS = auto()
-    CLASS_NAMES = auto()
+    SELECTOR = auto()
 
     TEXT = auto()
-    TITLE = auto()
-    PTEXT = auto()
+    FTEXT = auto()
     BTEXT = auto()
     ETEXT = auto()
-    ATTR_VALUE = auto()
-    ATTR_PVALUE = auto()
-    ATTR_BVALUE = auto()
-    ATTR_EVALUE = auto()
+    TITLE = auto()
+    ATTR = auto()
+    FATTR = auto()
+    BATTR = auto()
+    EATTR = auto()
     ATTR_WORD = auto()
     TYPE = auto()
     VALUE = auto()
     POINT = auto()
-    JAVASCRIPT = auto()
+    JS = auto()
 
     INDEX = auto()
     WINDOW_TITLE = auto()
     WINDOW_PTITLE = auto()
-    CONTENT_LOCATOR = auto()
-    GNS_NAME = auto()
+    ELEMENT = auto()
+    LABEL = auto()
 
 class With:
 
@@ -220,7 +218,7 @@ class With:
         self.__format_called = False
         self.__named_args = None
 
-        if with_type == WithType.CONTENT_LOCATOR:
+        if with_type == WithType.ELEMENT:
             if not isinstance(with_value, With):
                 raise Exception("For identification with element locator, the argument must be a With object.")
             else:
@@ -275,118 +273,126 @@ class With:
         
         return map
 
-    @staticmethod
-    def id(id):
+    @classmethod
+    def id(cls, id):
         return With(WithType.ID, id)
 
-    @staticmethod
-    def name(name):
+    @classmethod
+    def name(cls, name):
         return With(WithType.NAME, name)
 
-    @staticmethod
-    def class_name(name):
-        return With(WithType.CLASS_NAME, name)
+    @classmethod
+    def classes(cls, *names):
+        return With(WithType.CLASSES, names)
 
-    @staticmethod
-    def link_text(text):
-        return With(WithType.LINK_TEXT, text)
+    @classmethod
+    def link(cls, text):
+        return With(WithType.LINK, text)
 
-    @staticmethod
-    def link_ptext(text):
-        return With(WithType.LINK_PTEXT, text)
+    @classmethod
+    def flink(cls, text):
+        return With(WithType.FLINK, text)
 
-    @staticmethod
-    def css_selector(selector):
-        return With(WithType.CSS_SELECTOR, selector)
+    @classmethod
+    def selector(cls, selector):
+        return With(WithType.SELECTOR, selector)
 
-    @staticmethod
-    def tag_name(selector):
-        return With(WithType.TAG_NAME, selector)
+    @classmethod
+    def tag(cls, selector):
+        return With(WithType.TAG, selector)
 
-    @staticmethod
-    def xpath(xpath):
+    @classmethod
+    def xpath(cls, xpath):
         return With(WithType.XPATH, xpath)
 
-    @staticmethod
-    def text(text):
+    @classmethod
+    def text(cls, text):
         return With(WithType.TEXT, text)
 
-    @staticmethod
-    def ptext(text):
-        return With(WithType.PTEXT, text)
+    @classmethod
+    def ftext(cls, text):
+        return With(WithType.FTEXT, text)
 
-    @staticmethod
-    def btext(text):
+    @classmethod
+    def btext(cls, text):
         return With(WithType.BTEXT, text)
 
-    @staticmethod
-    def etext(text):
+    @classmethod
+    def etext(cls, text):
         return With(WithType.ETEXT, text)
 
-    @staticmethod
-    def title(title):
+    @classmethod
+    def title(cls, title):
         return With(WithType.TITLE, title)
 
-    @staticmethod
-    def attr_value(value):
-        return With(WithType.ATTR_VALUE, value)
+    @classmethod
+    def __fmt_attr(cls, attr, value):
+        return "[{}][{}]".format(attr, value)
 
-    @staticmethod
-    def attr_pvalue(value):
-        return With(WithType.ATTR_PVALUE, value)
+    @classmethod
+    def _attr(cls, fmt):
+        return With(WithType.ATTR, fmt)
 
-    @staticmethod
-    def attr_bvalue(value):
-        return With(WithType.ATTR_BVALUE, value)
+    @classmethod
+    def _fattr(cls, fmt):
+        return With(WithType.FATTR, fmt)
 
-    @staticmethod
-    def attr_evalue(value):
-        return With(WithType.ATTR_EVALUE, value)
+    @classmethod
+    def _battr(cls, fmt):
+        return With(WithType.BATTR, fmt)
 
-    @staticmethod
-    def attr_word(value):
-        return With(WithType.ATTR_WORD, value)
+    @classmethod
+    def _eattr(cls, fmt):
+        return With(WithType.EATTR, fmt)   
 
-    @staticmethod
-    def value(value):
+    @classmethod
+    def attr(cls, attr, value):
+        return _attr(cls.__fmt_attr(attr_value))
+
+    @classmethod
+    def fattr(cls, attr, content):
+        return _fattr(cls.__fmt_attr(attr_value))
+
+    @classmethod
+    def battr(cls, attr, content):
+        return _battr(cls.__fmt_attr(attr_value))
+
+    @classmethod
+    def eattr(cls, attr, content):
+        return _eattr(cls.__fmt_attr(attr_value))
+
+    @classmethod
+    def value(cls, value):
         return With(WithType.VALUE, value)
 
-    @staticmethod
-    def type(type):
+    @classmethod
+    def type(cls, type):
         return With(WithType.TYPE, type)
 
-    @staticmethod
-    def compound_class(classes_str):
-        return With(WithType.COMPOUND_CLASS, classes_str)
-
-    @staticmethod
-    def class_names(*class_names):
-        return With(WithType.CLASS_NAMES, class_names)
-
-    @staticmethod
-    def point(point):
+    @classmethod
+    def point(cls, point):
         return With(WithType.POINT, point.location)
 
-    @staticmethod
-    def javascript(js):
-        return With(WithType.JAVASCRIPT, js)
+    @classmethod
+    def js(cls, js):
+        return With(WithType.JS, js)
 
-    @staticmethod
-    def index(index):
+    @classmethod
+    def index(cls, index):
         return With(WithType.INDEX, index)
 
-    @staticmethod
-    def window_title(title):
+    @classmethod
+    def window_title(cls, title):
         return With(WithType.WINDOW_TITLE, title)
 
-    @staticmethod
-    def window_ptitle(ptitle):
+    @classmethod
+    def window_ptitle(cls, ptitle):
         return With(WithType.WINDOW_PTITLE, ptitle)
 
-    @staticmethod
-    def content_locator(with_obj):
-        return With(WithType.CONTENT_LOCATOR, with_obj)
+    @classmethod
+    def element(cls, with_obj):
+        return With(WithType.ELEMENT, with_obj)
 
-    @staticmethod
-    def gns_name(name):
-        return With(WithType.GNS_NAME, name)
\ No newline at end of file
+    @classmethod
+    def label(cls, name):
+        return With(WithType.LABEL, name)
\ No newline at end of file
