@@ -124,13 +124,11 @@ class FileObjectType(Enum):
 class CreateProject(Command):
 
     COMMON_DIRS_FILES = (
-        (FileObjectType.DIR, "archives"),
         (FileObjectType.DIR, "config"),
         (FileObjectType.DIR, "data"),
         (FileObjectType.DIR, "data/sources"),
         (FileObjectType.DIR, "data/references"),
         (FileObjectType.DIR, "guiauto"),
-        (FileObjectType.DIR, "log"),
         (FileObjectType.DIR, "guiauto/drivers"),
         (FileObjectType.DIR, "guiauto/drivers/linux"),
         (FileObjectType.DIR, "guiauto/drivers/mac"),
@@ -201,14 +199,12 @@ class __RunCommand(Command):
             parent.process(arg_dict)
 
         from arjuna import Arjuna
-        project_root_dir = arg_dict["project.root.dir"]
-        del arg_dict["project.root.dir"]
-        runid = arg_dict["run.id"]
-        del arg_dict["run.id"]
-
+        project_root_dir = arg_dict.pop("project.root.dir")
+        runid = arg_dict.pop("run.id")
+        static_rid = arg_dict.pop("static.rid")
         self.enumerate_only = arg_dict.pop("enumerate")
 
-        Arjuna.init(project_root_dir, CliArgsConfig(arg_dict).as_map(), runid)
+        Arjuna.init(project_root_dir, CliArgsConfig(arg_dict).as_map(), runid, static_rid=static_rid)
 
         import sys
         proj_dir = Arjuna.get_ref_config().get_arjuna_option_value(ArjunaOption.PROJECT_ROOT_DIR).as_str()
@@ -230,20 +226,20 @@ class RunProject(__RunCommand):
         test_runner.run(only_enumerate=self.enumerate_only)
 
 
-class RunPickers(__RunCommand):
+class RunSelected(__RunCommand):
 
     def __init__(self, subparsers, parents):
-        super().__init__(subparsers, 'run-pickers', parents, "Run tests based on pickers specified.")
+        super().__init__(subparsers, 'run-selected', parents, "Run tests selected based on selectors specified.")
 
     def execute(self, arg_dict):
         pickers_dict = dict()
         pickers = (
             ('cmodules', 'cm'),
             ('imodules', 'im'),
-            ('cclasses', 'cc'),
-            ('iclasses', 'ic'),
-            ('cfunctions', 'cfn'),
-            ('ifunctions', 'ifn'),
+            # ('cclasses', 'cc'),
+            # ('iclasses', 'ic'),
+            ('ctests', 'ct'),
+            ('itests', 'it'),
             )
 
         def process_picker(sname, tname):
